import java.io.*;

public class ModuleResult implements Serializable
{
	private Module currentModule;
	private String assessedModule;
	private int examMark;
	private int courseworkMark;
	private int totalMark;

	/**
	The ModuleResult class enables an object that represents the 
statistics of an assessment for a single module.
	@param module is the Module being assessed.
	@param exam is the percentage examination mark.
	@param coursework is the percentage coursework mark.
	*/
	public ModuleResult(Module module, int exam, int coursework)
	{
		currentModule = module;
		assessedModule = currentModule.getModuleName();
		examMark = exam;
		courseworkMark = coursework;
		totalMark = (currentModule.getExamRatio() * examMark /100) + 
			      (currentModule.getCourseworkRatio() * 
                         courseworkMark / 100);
	}

	/**
	Get name of module that was assessed.
	@return The name of the module.
	*/
	public String getModuleName()
	{
		return assessedModule;
	}
	

	/**
	Get the percentage examination mark.
	@return The percentage examination mark.
	*/
	public int getExamMark()
	{
		return examMark;
	}

	/**
	Get the percentage coursework mark.
	@return The percentage coursework mark.
	*/
	public int getCourseworkMark()
	{
		return courseworkMark;
	}

	/**
	Get the total mark after the examination and coursework weightings
	have been applied.
	@return Total mark as a percentage.
	*/
	public int getTotalMark()
	{
		return totalMark;
	}

	/**
	Compute the grade based upon the total mark.
	@return The grade.
	*/
	public String getGrade()
	{
		if      (totalMark >= 85) return "A";
		else if (totalMark >= 70) return "B+";
		else if (totalMark >= 55) return "B";
		else if (totalMark >= 40) return "C";
		else				  return "F";
	}			
}
