import java.io.*;
import java.util.*;

public class StudentProgram implements Serializable
{
	private String studentName;
	private Degree degree;
	private Vector studentRecord;

	/**
	The StudentProgram class enables an object that represents
	the registration of a student on a degree. This object also
	maintains a record of the student's progress by recording
	details of the modules assessed.
	@param name is the name of the student.
	@param registeredOn is the degree the student has joined.
	*/
	public StudentProgram(String name, Degree registeredOn)
	{
		studentName = name;
		degree = registeredOn;
		studentRecord = new Vector();
	}

	// instance methods
	/**
	Gets the name of the student.
	@return The name of the student.
	*/
	public String getStudentName()
	{
		return studentName;
	}

	/**
	Gets the degree the student has registered on.
	@return The degree the students has registered on.
	*/
	public Degree getDegree()
	{
		return degree;
	}

	/**
	Add the result from a module to the student program.
	@param module is the Module being assessed.
	@param exam is the percentage mark for the examination.
	@param coursework is the percentage mark for the coursework.
	*/
	public void addModuleResult(Module module, int exam, int coursework)
	{
		ModuleResult result = new 
            ModuleResult(module, exam, coursework);
		studentRecord.add(result);
	}

	/**
	Get the results from every module on the degree.
	@return A vector containing the result for each module taken.
	*/
	public Vector getStudentResults()
	{
		return studentRecord;
	}
}
